classdef regular_class_with_constructor < regular_class
    methods
      function obj = regular_class_with_constructor ()
        obj.a = 1;
        obj.b = 2;
        obj.c = 3;
        obj.d = 4;
        obj.e = 5;
      endfunction
    endmethods
endclassdef
